==> jquery-lte-1.0.1.tgz: package/src/bs/carousel.js <==
import {_boolean, __ as cls, bs, isElement, _array, _object} from "../utils/lib.js";
const { w, h, df, jcc, aic } = bs;

export default (_, items, options, existing) => {
    const __ = (className, tagName)=> cls.call(_, className, tagName);
    let carousel;
    let carouselContainer;
    const on = (event, callback) => {
        const cbs = {
            slide: 'slide.bs.carousel',
            slid: 'slid.bs.carousel'
        }
        carouselContainer.on(cbs[event], callback);
        return { on };
    }
    if (isElement(existing) && typeof options === 'number') {
        carousel = bootstrap.Carousel.getOrCreateInstance(existing);
        carousel.to(options);
        if (options === 0)
            carousel.cycle();

    } else if (_object(options, null)) {
        let {
            active,
            transition: tr,
            arrows,
            indicators: ind,
            interval,
            autostart,
            hover,
            keyboard,
            touch,
            recycle,
            theme,
            speed
        } = options;
        const themes = {
            dark: { bg: 'dark', txt: 'light' },
            light: { bg: 'light', txt: 'dark' }
        }
        if (!_array(items, null)) throw new Error('Carousel expects valid items')
        const trans = { slide: 'slide', fade: 'carousel-fade' };
        tr = trans[(tr || '').toLowerCase()] || 'slide';
        carouselContainer = __(`carousel bg-${(themes[theme] ||{bg:'light'}).bg} carousel-${(themes[theme] || {txt: 'dark'}).txt} ${tr}`).addClass([h, w]);
        const inner = __('carousel-inner').addClass([h, w]);
        const indicatorsContainer = __('carousel-indicators');
        const indicators = items.map((slide, index) => {
            const _bt = _('<button/>');
            let act = index == (typeof active === 'number' ? active : 0);
            act && _bt.addClass('active').attr({ 'aria-current': "true" });
            return _bt.attr({
                'data-bs-target': ''
            }).on('click', () => carousel.to(index))
        });
        let playingSlide = null;
        carousel = new bootstrap.Carousel(carouselContainer.plain(0), {
            wrap: _boolean(recycle, true),
            interval: interval === true ? 5000 : typeof interval === 'number' ? interval : _boolean(interval, 5000),
            touch: _boolean(touch, true),
            keyboard: _boolean(keyboard, true),
            pause: hover === 'hover' ? 'hover' : _boolean(hover, 'hover')
        })
        const next = __('carousel-control-next', 'button').on('click', function() { carousel.next() });
        const prev = __('carousel-control-prev', 'button').on('click', function() { carousel.prev() });
        inner.addChild(items.map((item, index) => {
            let slide_ = __([`carousel-item`, h, w]);
            let trans = item.interval;
            index == (active || 0) && slide_.addClass('active');
            if (item && typeof item === 'object' && item.item) {
                let type = typeof item.type === 'string' ? item.type : '';
                let fill = item.fill;
                let _item = item.item;
                let controls = item.controls;
                let autoplay = item.autoplay;
                if (['picture', 'video'].includes(type) && _item.split(' ').length === 1) {
                    item = _('<img/>').attr({ src: _item });
                    if (type === 'video') {
                        item = _('<video/>').attr({ src: _item, _autoplay: _boolean(autoplay, true) });
                        item.plain(0).controls = _boolean(controls, true);
                    }
                    if (_boolean(fill, true))
                        item.addClass([w, h]).style({ objectFit: 'cover' });
                    else
                        item.style({
                            maxWidth: '100%',
                            maxHeight: '100%'
                        })
                } else
                    item = item.item;
            }

            if (trans && typeof trans === 'number')
                slide_.attr({ 'data-bs-interval': trans });

            slide_.addChild(__([h, w, df, jcc, aic]).addChild(item))
            if(typeof speed == 'number')
               slide_.style({transitionDuration: `${speed}ms`});
            return slide_;
        }));

        indicatorsContainer.addChild(indicators);

        next.addChild([
            __('carousel-control-next-icon', 'span').attr({ 'aria-hidden': 'true' }),
            __('visually-hidden', 'span').addChild('Next')
        ])

        prev.addChild([
            __('carousel-control-prev-icon', 'span').attr({ 'aria-hidden': 'true' }),
            __('visually-hidden', 'span').addChild('Previous')
        ])

        _boolean(ind, true) && carouselContainer.addChild(indicatorsContainer);
        carouselContainer.addChild(inner);
        _boolean(arrows, true) && carouselContainer.addChild([prev, next]);
        on('slid', function(e) {
            _(indicators[e.from]).removeClass('active');
            _(indicators[e.to]).addClass('active');
        })
        on('slid', e => {
            if (playingSlide) {
                playingSlide.pause();
                playingSlide.currentTime = 0;
            }
            let vid = _(carousel._items[e.to]).child(0).child(0);
            if (!isElement(vid) || vid.tagName() != 'VIDEO' || vid.attr('_autoplay') != 'true') return;
            vid.play().then(() => {
                playingSlide = vid;
                carousel.pause();
                vid.on('ended', function() { recycle && carousel.cycle() })
            }).catch(e => {});
        })
        carousel._items = [_('</>').plain(0)];
        _boolean(autostart, true) && carousel.cycle();
    }
    return {
        to(n){
            return carousel.to(n);
        },
        next(){
            return carousel.next();
        },
        cycle(){
            return carousel.cycle();
        },
        pause(){
            return carousel.pause();
        },

        /**
         * Attach eventListeners to modal
         * @param {'slide' | 'slid'} event 
         * @param {Function} callback 
         */

        on(event, callback){
           return on(event, callback);
        },
        container: carouselContainer,
        appendTo(container){
           return carouselContainer.appendTo(container)
        },
        i: carousel
    };
}

==> jquery-lte-1.0.3.tgz: package/src/bs/carousel.js <==
import {_boolean, __ as cls, bs, isElement, _array, _object} from "../utils/lib.js";
const { w, h, df, jcc, aic } = bs;

export default (_, items, options, existing) => {
    const _bootstrap = typeof bootstrap === 'undefined' ? require('bootstrap') : bootstrap;
    const __ = (className, tagName)=> cls.call(_, className, tagName);
    let carousel;
    let carouselContainer;
    const on = (event, callback) => {
        const cbs = {
            slide: 'slide.bs.carousel',
            slid: 'slid.bs.carousel'
        }
        carouselContainer.on(cbs[event], callback);
        return { on };
    }
    if (isElement(existing) && typeof options === 'number') {
        carousel = _bootstrap.Carousel.getOrCreateInstance(existing);
        carousel.to(options);
        if (options === 0)
            carousel.cycle();

    } else if (_object(options, null)) {
        let {
            active,
            transition: tr,
            arrows,
            indicators: ind,
            interval,
            autostart,
            hover,
            keyboard,
            touch,
            recycle,
            theme,
            speed
        } = options;
        const themes = {
            dark: { bg: 'dark', txt: 'light' },
            light: { bg: 'light', txt: 'dark' }
        }
        if (!_array(items, null)) throw new Error('Carousel expects valid items')
        const trans = { slide: 'slide', fade: 'carousel-fade' };
        tr = trans[(tr || '').toLowerCase()] || 'slide';
        carouselContainer = __(`carousel bg-${(themes[theme] ||{bg:'light'}).bg} carousel-${(themes[theme] || {txt: 'dark'}).txt} ${tr}`).addClass([h, w]);
        const inner = __('carousel-inner').addClass([h, w]);
        const indicatorsContainer = __('carousel-indicators');
        const indicators = items.map((slide, index) => {
            const _bt = _('<button/>');
            let act = index == (typeof active === 'number' ? active : 0);
            act && _bt.addClass('active').attr({ 'aria-current': "true" });
            return _bt.attr({
                'data-bs-target': ''
            }).on('click', () => carousel.to(index))
        });
        let playingSlide = null;
        carousel = new _bootstrap.Carousel(carouselContainer.plain(0), {
            wrap: _boolean(recycle, true),
            interval: interval === true ? 5000 : typeof interval === 'number' ? interval : _boolean(interval, 5000),
            touch: _boolean(touch, true),
            keyboard: _boolean(keyboard, true),
            pause: hover === 'hover' ? 'hover' : _boolean(hover, 'hover')
        })
        const next = __('carousel-control-next', 'button').on('click', function() { carousel.next() });
        const prev = __('carousel-control-prev', 'button').on('click', function() { carousel.prev() });
        inner.addChild(items.map((item, index) => {
            let slide_ = __([`carousel-item`, h, w]);
            let trans = item.interval;
            index == (active || 0) && slide_.addClass('active');
            if (item && typeof item === 'object' && item.item) {
                let type = typeof item.type === 'string' ? item.type : '';
                let fill = item.fill;
                let _item = item.item;
                let controls = item.controls;
                let autoplay = item.autoplay;
                if (['picture', 'video'].includes(type) && _item.split(' ').length === 1) {
                    item = _('<img/>').attr({ src: _item });
                    if (type === 'video') {
                        item = _('<video/>').attr({ src: _item, _autoplay: _boolean(autoplay, true) });
                        item.plain(0).controls = _boolean(controls, true);
                    }
                    if (_boolean(fill, true))
                        item.addClass([w, h]).style({ objectFit: 'cover' });
                    else
                        item.style({
                            maxWidth: '100%',
                            maxHeight: '100%'
                        })
                } else
                    item = item.item;
            }

            if (trans && typeof trans === 'number')
                slide_.attr({ 'data-bs-interval': trans });

            slide_.addChild(__([h, w, df, jcc, aic]).addChild(item))
            if(typeof speed == 'number')
               slide_.style({transitionDuration: `${speed}ms`});
            return slide_;
        }));

        indicatorsContainer.addChild(indicators);

        next.addChild([
            __('carousel-control-next-icon', 'span').attr({ 'aria-hidden': 'true' }),
            __('visually-hidden', 'span').addChild('Next')
        ])

        prev.addChild([
            __('carousel-control-prev-icon', 'span').attr({ 'aria-hidden': 'true' }),
            __('visually-hidden', 'span').addChild('Previous')
        ])

        _boolean(ind, true) && carouselContainer.addChild(indicatorsContainer);
        carouselContainer.addChild(inner);
        _boolean(arrows, true) && carouselContainer.addChild([prev, next]);
        on('slid', function(e) {
            _(indicators[e.from]).removeClass('active');
            _(indicators[e.to]).addClass('active');
        })
        on('slid', e => {
            if (playingSlide) {
                playingSlide.pause();
                playingSlide.currentTime = 0;
            }
            let vid = _(carousel._items[e.to]).child(0).child(0);
            if (!isElement(vid) || vid.tagName() != 'VIDEO' || vid.attr('_autoplay') != 'true') return;
            vid.play().then(() => {
                playingSlide = vid;
                carousel.pause();
                vid.on('ended', function() { recycle && carousel.cycle() })
            }).catch(e => {});
        })
        carousel._items = [_('</>').plain(0)];
        _boolean(autostart, true) && carousel.cycle();
    }
    return {
        to(n){
            return carousel.to(n);
        },
        next(){
            return carousel.next();
        },
        cycle(){
            return carousel.cycle();
        },
        pause(){
            return carousel.pause();
        },

        /**
         * Attach eventListeners to modal
         * @param {'slide' | 'slid'} event 
         * @param {Function} callback 
         */

        on(event, callback){
           return on(event, callback);
        },
        container: carouselContainer,
        appendTo(container){
           return carouselContainer.appendTo(container)
        },
        i: carousel
    };
}
